import 'dart:io';

import 'package:decorated_flutter/decorated_flutter.dart';
import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:nim_fluttify/nim_fluttify.dart';
import 'package:nim_fluttify_example/src/mixins.dart';

class SendFileScreen extends StatefulWidget {
  @override
  _SendFileScreenState createState() => _SendFileScreenState();
}

class _SendFileScreenState extends State<SendFileScreen>
    with AccountTokenMixin {
  File _file;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: Text('发送文件消息')),
      body: Center(
        child: DecoratedColumn(
          scrollable: true,
          padding: EdgeInsets.all(kSpaceBig),
          children: <Widget>[
            Text('发送方: $testAccount'),
            Text('单聊接收方: $peerAccount'),
            Text('聊天室id: $chatRoomId'),
            RaisedButton(
              onPressed: _handlePickFile,
              child: Text('选择文件'),
            ),
            if (_file != null) Text('文件路径: ${_file.path}'),
            RaisedButton(
              onPressed: _handleSendImage,
              child: Text('发送单聊信息'),
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                RaisedButton(
                  onPressed: handleEnterChatRoom,
                  child: Text('进入聊天室'),
                ),
                SPACE_NORMAL,
                RaisedButton(
                  onPressed: _handleSendChatRoomFile,
                  child: Text('发送聊天室信息'),
                ),
              ],
            ),
          ],
        ),
      ),
    );
  }

  void _handleSendImage() async {
    if (_file != null) {
      Nim.instance
          .sendFileMessage(
            sessionId: peerAccount,
            type: SessionType.p2p,
            file: _file,
          )
          .loading(context)
          .then((value) => toast('发送成功'))
          .catchError(handle(context));
    } else {
      toast('发送内容不能为空');
    }
  }

  void _handleSendChatRoomFile() async {
    if (_file != null) {
      Nim.instance
          .sendFileMessage(
            sessionId: chatRoomId,
            type: SessionType.chatroom,
            file: _file,
          )
          .loading(context)
          .then((value) => toast('发送成功'))
          .catchError(handle(context));
    } else {
      toast('发送内容不能为空');
    }
  }

  void _handlePickFile() async {
    File file = await FilePicker.getFile();
    setState(() {
      _file = file;
    });
  }
}
