import 'dart:io';

import 'package:decorated_flutter/decorated_flutter.dart';
import 'package:flutter/material.dart';
import 'package:image_picker/image_picker.dart';
import 'package:nim_fluttify/nim_fluttify.dart';
import 'package:nim_fluttify_example/src/mixins.dart';

class SendImageScreen extends StatefulWidget {
  @override
  _SendImageScreenState createState() => _SendImageScreenState();
}

class _SendImageScreenState extends State<SendImageScreen>
    with AccountTokenMixin {
  File _imageFile;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: Text('发送图片消息')),
      body: Center(
        child: DecoratedColumn(
          scrollable: true,
          padding: EdgeInsets.all(kSpaceBig),
          children: <Widget>[
            Text('发送方: $testAccount'),
            Text('单聊接收方: $peerAccount'),
            Text('聊天室id: $chatRoomId'),
            RaisedButton(
              onPressed: _handlePickImage,
              child: Text('选择图片'),
            ),
            if (_imageFile != null) Image.file(_imageFile),
            RaisedButton(
              onPressed: _handleSendImage,
              child: Text('发送单聊信息'),
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                RaisedButton(
                  onPressed: handleEnterChatRoom,
                  child: Text('进入聊天室'),
                ),
                SPACE_NORMAL,
                RaisedButton(
                  onPressed: _handleSendChatRoomImage,
                  child: Text('发送聊天室信息'),
                ),
              ],
            ),
          ],
        ),
      ),
    );
  }

  void _handleSendImage() async {
    if (_imageFile != null) {
      Nim.instance
          .sendImageMessage(
            sessionId: peerAccount,
            type: SessionType.p2p,
            imageFile: _imageFile,
          )
          .loading(context)
          .then((value) => toast('发送成功'))
          .catchError(handle(context));
    } else {
      toast('发送内容不能为空');
    }
  }

  void _handleSendChatRoomImage() async {
    if (_imageFile != null) {
      Nim.instance
          .sendImageMessage(
            sessionId: chatRoomId,
            type: SessionType.chatroom,
            imageFile: _imageFile,
          )
          .loading(context)
          .then((value) => toast('发送成功'))
          .catchError(handle(context));
    } else {
      toast('发送内容不能为空');
    }
  }

  void _handlePickImage() async {
    final image = await ImagePicker.pickImage(source: ImageSource.gallery);
    setState(() {
      _imageFile = image;
    });
  }
}
