import 'package:decorated_flutter/decorated_flutter.dart';
import 'package:flutter/material.dart';
import 'package:nim_fluttify/nim_fluttify.dart';
import 'package:nim_fluttify_example/src/mixins.dart';

class FriendListScreen extends StatefulWidget {
  @override
  _FriendListScreenState createState() => _FriendListScreenState();
}

class _FriendListScreenState extends State<FriendListScreen>
    with AccountTokenMixin {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: Text('好友列表')),
      body: PreferredFutureBuilder<List<FriendVM>>(
        future: _fetchFriendList(),
        builder: (data) {
          return ListView.builder(
            itemCount: data.length,
            itemBuilder: (context, index) {
              return _FriendItem(data[index]);
            },
          );
        },
      ),
    );
  }

  Future<List<FriendVM>> _fetchFriendList() async {
    final friendList = await Nim.instance.fetchMyFriendList();
    return [for (final friend in friendList) await FriendVM.data(friend)];
  }
}

class FriendVM {
  static Future<FriendVM> data(NimUser data) async {
    return FriendVM()
      ..account = await data.account
      ..gender = await data.gender
      ..email = await data.email
      ..avatar = await data.avatar
      ..mobile = await data.mobile
      ..signature = await data.signature
      ..nickname = await data.nickname
      ..birthday = await data.birthday;
  }

  String account;
  String email;
  String avatar;
  String birthday;
  String mobile;
  String nickname;
  String signature;
  Gender gender;
}

class _FriendItem extends StatelessWidget {
  const _FriendItem(this.vm, {Key key}) : super(key: key);

  final FriendVM vm;

  @override
  Widget build(BuildContext context) {
    return Card(
      child: DecoratedColumn(
        padding: EdgeInsets.all(kSpaceNormal),
        children: <Widget>[
          Text('好友账号: ${vm.account}'),
          Text('好友性别: ${vm.gender}'),
          Text('好友邮箱: ${vm.email}'),
          Text('好友头像: ${vm.avatar}'),
          Text('好友手机号: ${vm.mobile}'),
          Text('好友昵称: ${vm.nickname}'),
          Text('好友生日: ${vm.birthday}'),
        ],
      ),
    );
  }
}
